@@ -12,7 +12,7 @@ use warnings;
 use utf8;
 use open qw(:std :utf8);
 package App::SpreadRevolutionaryDate;
-$App::SpreadRevolutionaryDate::VERSION = '0.04';
+$App::SpreadRevolutionaryDate::VERSION = '0.05';
 # ABSTRACT: Spread date and time from Revolutionary (Republican) Calendar on Twitter, Mastodon and Freenode.
 
 use App::SpreadRevolutionaryDate::Config;
@@ -96,7 +96,7 @@ App::SpreadRevolutionaryDate - Spread date and time from Revolutionary (Republic
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 METHODS
 
@@ -106,7 +106,7 @@ Constructor class method. Takes one optional argument: C<$filename> which should
 
 =head2 spread
 
-Spreads calendar date to configured targets. Takes one optional boolean argument, if true (default) authentication and spreading to Freenode is performed, otherwise, you've got to run C<use POE; POE::Kernel->run();> to do so. This is only used for testing, when multiple bots are needed. You can safely leave this optional argument unset.
+Spreads calendar date to configured targets. Takes one optional boolean argument, if true (default) authentication and spreading to Freenode is performed, otherwise, you've got to run C<use POE; POE::Kernel-E<gt>run();> to do so. This is only used for testing, when multiple bots are needed. You can safely leave this optional argument unset.
 
 =head1 AUTHOR
 
