@@ -8,11 +8,11 @@
 #   The GNU General Public License, Version 3, June 2007
 #
 use strict;
-no warnings;
+use warnings;
 use utf8;
 use open qw(:std :utf8);
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.04';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.05';
 # ABSTRACT: Subclass of L<App::SpreadRevolutionaryDate> to handle configuration file and command line arguments.
 
 use AppConfig qw(:argcount);
@@ -101,7 +101,7 @@ App::SpreadRevolutionaryDate::Config - Subclass of L<App::SpreadRevolutionaryDat
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 METHODS
 
